@@ -1,6 +1,6 @@
 #!/bin/bash -
 # libguestfs virt-inspector test script
-# Copyright (C) 2012-2023 Red Hat Inc.
+# Copyright (C) 2012-2025 Red Hat Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,10 +21,10 @@
 #
 # Regression test for https://bugzilla.redhat.com/show_bug.cgi?id=1602353
 
+source ../tests/functions.sh
 set -e
 set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 f=../test-data/phony-guests/fedora-lvm-on-luks.img
