@@ -1,6 +1,6 @@
 #!/bin/bash -
 # libguestfs virt-sparsify --in-place test script
-# Copyright (C) 2011-2023 Red Hat Inc.
+# Copyright (C) 2011-2025 Red Hat Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
+source ../tests/functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 rm -f test-virt-sparsify-in-place.img
